@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/tcop/fastpath.c,v 1.54 2002/08/24 15:00:46 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/tcop/fastpath.c,v 1.54.2.2 2003/01/05 00:49:59 tgl Exp $
  *
  * NOTES
  *	  This cruft is the server side of PQfn.
@@ -64,9 +64,12 @@
 #include "catalog/pg_proc.h"
 #include "libpq/libpq.h"
 #include "libpq/pqformat.h"
+#include "miscadmin.h"
 #include "tcop/fastpath.h"
+#include "utils/acl.h"
 #include "utils/lsyscache.h"
 #include "utils/syscache.h"
+#include "utils/tqual.h"
 
 
 /* ----------------
@@ -221,6 +224,7 @@ HandleFunctionRequest(void)
 	int			argsize;
 	int			nargs;
 	int			tmp;
+	AclResult	aclresult;
 	FunctionCallInfoData fcinfo;
 	Datum		retval;
 	int			i;
@@ -337,6 +341,18 @@ HandleFunctionRequest(void)
 		elog(ERROR, "current transaction is aborted, "
 			 "queries ignored until end of transaction block");
 
+	/* Check permission to call function */
+	aclresult = pg_proc_aclcheck(fid, GetUserId(), ACL_EXECUTE);
+	if (aclresult != ACLCHECK_OK)
+		aclcheck_error(aclresult, get_func_name(fid));
+
+	/*
+	 * Set up a query snapshot in case function needs one.  (It is not safe
+	 * to do this if we are in transaction-abort state, so we have to postpone
+	 * it till now.  Ugh.)
+	 */
+	SetQuerySnapshot();
+
 #ifdef NO_FASTPATH
 	/* force a NULL return */
 	retval = (Datum) 0;
